aboutsummaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/container.js11
1 files changed, 7 insertions, 4 deletions
diff --git a/src/container.js b/src/container.js
index 5aac877..46ebdb1 100644
--- a/src/container.js
+++ b/src/container.js
@@ -156,10 +156,13 @@ SVG.extend(SVG.Container, {
/* remove children */
for (var i = this.children().length - 1; i >= 0; i--)
this.removeElement(this.children()[i])
-
- /* create new defs node */
- this.defs()
-
+
+ /* remove defs node */
+ if (this._defs) {
+ this._defs.remove()
+ delete this._defs
+ }
+
return this
}